@@ -99,8 +99,15 @@ def _command_output(command, input=None, env=None):
     '''
     sp = subprocess.Popen(command, stdout=subprocess.PIPE,
                           stderr=subprocess.STDOUT, env=env)
-
-    out = sp.communicate(input)[0]
+    # gdb can timeout when trying to retrace some core files, giving it 30
+    # minutes to run should be more than enough.
+    try:
+        out = sp.communicate(input=input, timeout=1800)[0]
+    except subprocess.TimeoutExpired:
+        sp.kill()
+        out, errs = sp.communicate()
+        raise OSError('Error: command %s timedout with exit code %i: %s' % (
+            str(command), sp.returncode, out))
     if sp.returncode == 0:
         return out
     else:
@@ -725,7 +732,10 @@ class Report(problem_report.ProblemReport):
 
         # check for truncated stack trace
         if 'is truncated: expected core file size' in out:
-            warnings = '\n'.join([l for l in out.splitlines() if 'Warning:' in l])
+            if 'warning:' in out:
+                warnings = '\n'.join([l for l in out.splitlines() if 'warning:' in l])
+            elif 'Warning:' in out:
+                warnings = '\n'.join([l for l in out.splitlines() if 'Warning:' in l])
             reason = 'Invalid core dump: ' + warnings.strip()
             self['UnreportableReason'] = reason
             raise IOError(reason)
@@ -956,15 +966,25 @@ class Report(problem_report.ProblemReport):
         ifpath = os.path.expanduser(_ignore_file)
         if orig_home is not None:
             os.environ['HOME'] = orig_home
-        if not os.access(ifpath, os.R_OK) or os.path.getsize(ifpath) == 0:
+        euid = os.geteuid()
+        try:
+            # drop permissions temporarily to try open users ignore file
+            os.seteuid(os.getuid())
+            fp = open(ifpath, 'r')
+        except (IOError, OSError):
+            fp = None
+        finally:
+            os.seteuid(euid)
+        if fp is None or os.fstat(fp.fileno()).st_size == 0:
             # create a document from scratch
             dom = xml.dom.getDOMImplementation().createDocument(None, 'apport', None)
         else:
             try:
-                dom = xml.dom.minidom.parse(ifpath)
+                dom = xml.dom.minidom.parse(fp)
             except ExpatError as e:
                 raise ValueError('%s has invalid format: %s' % (_ignore_file, str(e)))
-
+        if fp is not None:
+            fp.close()
         # remove whitespace so that writing back the XML does not accumulate
         # whitespace
         dom.documentElement.normalize()
